/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'pl', {
	border: 'Pokaż obramowanie obiektu IFrame',
	noUrl: 'Podaj adres URL elementu IFrame',
	scrolling: 'Włącz paski przewijania',
	title: 'Właściwości elementu IFrame',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
